#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IInstallation_VERSION = "5.0.7574"


class IInstallation(BaseEndpoint):
    def __init__(self, apiKey, url):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/system/installation'

    def clone(self, sourceParams):
        postUri = "/_clone"
        __data__ = None
        __encoded__ = None
        from netbluemind.system.api.CloneConfiguration import CloneConfiguration
        from netbluemind.system.api.CloneConfiguration import __CloneConfigurationSerDer__
        __data__ = __CloneConfigurationSerDer__().encode(sourceParams)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def deleteLogo(self):
        postUri = "/logo"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def demoteLeader(self):
        postUri = "/state/_demote"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getHostReport(self):
        postUri = "/_hostReport"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(serder.STRING, response)

    def getInfos(self):
        postUri = "/_infos"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.system.api.PublicInfos import PublicInfos
        from netbluemind.system.api.PublicInfos import __PublicInfosSerDer__
        return self.handleResult__(__PublicInfosSerDer__(), response)

    def getLogo(self):
        postUri = "/logo"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.system.api.CustomLogo import CustomLogo
        from netbluemind.system.api.CustomLogo import __CustomLogoSerDer__
        return self.handleResult__(__CustomLogoSerDer__(), response)

    def getSubscriptionContacts(self):
        postUri = "/_subscriptionContacts"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def getSubscriptionInformations(self):
        postUri = "/subscription"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.system.api.SubscriptionInformations import SubscriptionInformations
        from netbluemind.system.api.SubscriptionInformations import __SubscriptionInformationsSerDer__
        return self.handleResult__(__SubscriptionInformationsSerDer__(), response)

    def getSubscriptionKind(self):
        postUri = "/subscriptionKind"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.system.api.SubscriptionInformationsKind import SubscriptionInformationsKind
        from netbluemind.system.api.SubscriptionInformationsKind import __SubscriptionInformationsKindSerDer__
        return self.handleResult__(__SubscriptionInformationsKindSerDer__(), response)

    def getSystemState(self):
        postUri = "/state"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.system.api.SystemState import SystemState
        from netbluemind.system.api.SystemState import __SystemStateSerDer__
        return self.handleResult__(__SystemStateSerDer__(), response)

    def getVersion(self):
        postUri = "/version"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.system.api.InstallationVersion import InstallationVersion
        from netbluemind.system.api.InstallationVersion import __InstallationVersionSerDer__
        return self.handleResult__(__InstallationVersionSerDer__(), response)

    def initialize(self):
        postUri = "/_initialize"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def isValidProductionSubscription(self):
        postUri = "/subscriptionProductiveValid"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(serder.BOOLEAN, response)

    def maintenanceMode(self):
        postUri = "/state/_maintenance"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def markSchemaAsUpgraded(self):
        postUri = "/version"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def ping(self, ip):
        postUri = "/{ip}/ping"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{ip}", ip)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def postinst(self):
        postUri = "/_postinst"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def promoteLeader(self):
        postUri = "/state/_promote"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def removeSubscription(self):
        postUri = "/subscription"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def resetIndex(self, index):
        postUri = "/{index}/_resetIndex"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{index}", index)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def resetIndexes(self):
        postUri = "/_resetIndexes"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def runningMode(self):
        postUri = "/state/_maintenance"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def sendHostReport(self):
        postUri = "/_hostReport"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(serder.STRING, response)

    def setLogo(self, logo):
        postUri = "/logo"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ByteArraySerDer.encode(logo)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setSubscriptionContacts(self, emails):
        postUri = "/_subscriptionContacts"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(emails)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def updateSubscription(self, licence):
        postUri = "/subscription"
        __data__ = None
        __encoded__ = None
        __data__ = serder.STRING.encode(licence)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def updateSubscriptionVersion(self, version):
        postUri = "/subscription/_version"
        __data__ = None
        __encoded__ = None
        queryParams = {'version': version}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def updateSubscriptionWithArchive(self, archive):
        postUri = "/subscription/_archive"
        __data__ = None
        __encoded__ = None
        __data__ = serder.STREAM.encode(archive)
        __encoded__ = __data__
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def upgrade(self):
        postUri = "/_upgrade"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def upgradeStatus(self):
        postUri = "/_upgrade"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IInstallation_VERSION}, data=__encoded__)
        from netbluemind.system.api.UpgradeStatus import UpgradeStatus
        from netbluemind.system.api.UpgradeStatus import __UpgradeStatusSerDer__
        return self.handleResult__(__UpgradeStatusSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class ICalendarElementOrganizer:
    def __init__(self):
        self.uri = None
        self.commonName = None
        self.mailto = None
        self.dir = None
        pass


class __ICalendarElementOrganizerSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ICalendarElementOrganizer()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        uriValue = value['uri']
        instance.uri = serder.STRING.parse(uriValue)
        commonNameValue = value['commonName']
        instance.commonName = serder.STRING.parse(commonNameValue)
        mailtoValue = value['mailto']
        instance.mailto = serder.STRING.parse(mailtoValue)
        dirValue = value['dir']
        instance.dir = serder.STRING.parse(dirValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        uriValue = value.uri
        instance["uri"] = serder.STRING.encode(uriValue)
        commonNameValue = value.commonName
        instance["commonName"] = serder.STRING.encode(commonNameValue)
        mailtoValue = value.mailto
        instance["mailto"] = serder.STRING.encode(mailtoValue)
        dirValue = value.dir
        instance["dir"] = serder.STRING.encode(dirValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IMailboxIdentity_VERSION = "5.0.7574"


class IMailboxIdentity(BaseEndpoint):
    def __init__(self, apiKey, url, domainUid, mboxUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/mailboxes/{domainUid}/identity/{mboxUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}', domainUid)
        self.mboxUid_ = mboxUid
        self.base = self.base.replace('{mboxUid}', mboxUid)

    def create(self, uid, identity):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.mailbox.identity.api.Identity import Identity
        from netbluemind.mailbox.identity.api.Identity import __IdentitySerDer__
        __data__ = __IdentitySerDer__().encode(identity)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxIdentity_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def delete(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxIdentity_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def get(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxIdentity_VERSION}, data=__encoded__)
        from netbluemind.mailbox.identity.api.Identity import Identity
        from netbluemind.mailbox.identity.api.Identity import __IdentitySerDer__
        return self.handleResult__(__IdentitySerDer__(), response)

    def getIdentities(self):
        postUri = ""
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxIdentity_VERSION}, data=__encoded__)
        from netbluemind.mailbox.identity.api.IdentityDescription import IdentityDescription
        from netbluemind.mailbox.identity.api.IdentityDescription import __IdentityDescriptionSerDer__
        return self.handleResult__(serder.ListSerDer(__IdentityDescriptionSerDer__()), response)

    def getPossibleIdentities(self):
        postUri = "/_possible"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxIdentity_VERSION}, data=__encoded__)
        from netbluemind.mailbox.identity.api.IdentityDescription import IdentityDescription
        from netbluemind.mailbox.identity.api.IdentityDescription import __IdentityDescriptionSerDer__
        return self.handleResult__(serder.ListSerDer(__IdentityDescriptionSerDer__()), response)

    def update(self, uid, identity):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.mailbox.identity.api.Identity import Identity
        from netbluemind.mailbox.identity.api.Identity import __IdentitySerDer__
        __data__ = __IdentitySerDer__().encode(identity)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxIdentity_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class JobDomainStatus:
    def __init__(self):
        self.domain = None
        self.status = None
        pass


class __JobDomainStatusSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = JobDomainStatus()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        domainValue = value['domain']
        instance.domain = serder.STRING.parse(domainValue)
        from netbluemind.scheduledjob.api.JobExitStatus import JobExitStatus
        from netbluemind.scheduledjob.api.JobExitStatus import __JobExitStatusSerDer__
        statusValue = value['status']
        instance.status = __JobExitStatusSerDer__().parse(statusValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        domainValue = value.domain
        instance["domain"] = serder.STRING.encode(domainValue)
        from netbluemind.scheduledjob.api.JobExitStatus import JobExitStatus
        from netbluemind.scheduledjob.api.JobExitStatus import __JobExitStatusSerDer__
        statusValue = value.status
        instance["status"] = __JobExitStatusSerDer__().encode(statusValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IMailboxMgmt_VERSION = "5.0.7574"


class IMailboxMgmt(BaseEndpoint):
    def __init__(self, apiKey, url, domainUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/mgmt/mailbox/{domainUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}', domainUid)

    def addIndexToRing(self, numericIndex):
        postUri = "/{numericIndex}/_add_index"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{numericIndex}", numericIndex)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def consolidateDomain(self):
        postUri = "/_consolidate"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def consolidateMailbox(self, mailboxUid):
        postUri = "/{mailboxUid}/_consolidate"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def deleteIndexFromRing(self, numericIndex):
        postUri = "/{numericIndex}/_remove_index"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{numericIndex}", numericIndex)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def getLiteStats(self):
        postUri = "/liteStats"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.SimpleShardStats import SimpleShardStats
        from netbluemind.mailbox.api.SimpleShardStats import __SimpleShardStatsSerDer__
        return self.handleResult__(serder.ListSerDer(__SimpleShardStatsSerDer__()), response)

    def getShardsStats(self):
        postUri = "/shardsStats"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
        from netbluemind.mailbox.api.ShardStats import ShardStats
        from netbluemind.mailbox.api.ShardStats import __ShardStatsSerDer__
        return self.handleResult__(serder.ListSerDer(__ShardStatsSerDer__()), response)

    def moveIndex(self, mailboxUid, index, deleteSource):
        postUri = "/{mailboxUid}/_move_index"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        queryParams = {'index': index, 'deleteSource': deleteSource}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def resetMailbox(self, mailboxUid):
        postUri = "/{mailboxUid}/_reset"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def respawnMailbox(self, mailboxUid):
        postUri = "/{mailboxUid}/_respawn"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{mailboxUid}", mailboxUid)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IMailboxMgmt_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class Conversation:
    def __init__(self):
        self.messageRefs = None
        self.conversationId = None
        self.conversationUid = None
        pass


class __ConversationSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = Conversation()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.backend.mail.api.ConversationMessageRef import ConversationMessageRef
        from netbluemind.backend.mail.api.ConversationMessageRef import __ConversationMessageRefSerDer__
        messageRefsValue = value['messageRefs']
        instance.messageRefs = serder.ListSerDer(
            __ConversationMessageRefSerDer__()).parse(messageRefsValue)
        conversationIdValue = value['conversationId']
        instance.conversationId = serder.LONG.parse(conversationIdValue)
        conversationUidValue = value['conversationUid']
        instance.conversationUid = serder.STRING.parse(conversationUidValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.backend.mail.api.ConversationMessageRef import ConversationMessageRef
        from netbluemind.backend.mail.api.ConversationMessageRef import __ConversationMessageRefSerDer__
        messageRefsValue = value.messageRefs
        instance["messageRefs"] = serder.ListSerDer(
            __ConversationMessageRefSerDer__()).encode(messageRefsValue)
        conversationIdValue = value.conversationId
        instance["conversationId"] = serder.LONG.encode(conversationIdValue)
        conversationUidValue = value.conversationUid
        instance["conversationUid"] = serder.STRING.encode(
            conversationUidValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class VEventCounter:
    def __init__(self):
        self.originator = None
        self.counter = None
        pass


class __VEventCounterSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = VEventCounter()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.calendar.api.VEventCounterCounterOriginator import VEventCounterCounterOriginator
        from netbluemind.calendar.api.VEventCounterCounterOriginator import __VEventCounterCounterOriginatorSerDer__
        originatorValue = value['originator']
        instance.originator = __VEventCounterCounterOriginatorSerDer__().parse(originatorValue)
        from netbluemind.calendar.api.VEventOccurrence import VEventOccurrence
        from netbluemind.calendar.api.VEventOccurrence import __VEventOccurrenceSerDer__
        counterValue = value['counter']
        instance.counter = __VEventOccurrenceSerDer__().parse(counterValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.calendar.api.VEventCounterCounterOriginator import VEventCounterCounterOriginator
        from netbluemind.calendar.api.VEventCounterCounterOriginator import __VEventCounterCounterOriginatorSerDer__
        originatorValue = value.originator
        instance["originator"] = __VEventCounterCounterOriginatorSerDer__().encode(
            originatorValue)
        from netbluemind.calendar.api.VEventOccurrence import VEventOccurrence
        from netbluemind.calendar.api.VEventOccurrence import __VEventOccurrenceSerDer__
        counterValue = value.counter
        instance["counter"] = __VEventOccurrenceSerDer__().encode(counterValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class TagChanges:
    def __init__(self):
        self.add = None
        self.modify = None
        self.delete = None
        pass


class __TagChangesSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = TagChanges()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.tag.api.TagChangesItemAdd import TagChangesItemAdd
        from netbluemind.tag.api.TagChangesItemAdd import __TagChangesItemAddSerDer__
        addValue = value['add']
        instance.add = serder.ListSerDer(
            __TagChangesItemAddSerDer__()).parse(addValue)
        from netbluemind.tag.api.TagChangesItemModify import TagChangesItemModify
        from netbluemind.tag.api.TagChangesItemModify import __TagChangesItemModifySerDer__
        modifyValue = value['modify']
        instance.modify = serder.ListSerDer(
            __TagChangesItemModifySerDer__()).parse(modifyValue)
        from netbluemind.tag.api.TagChangesItemDelete import TagChangesItemDelete
        from netbluemind.tag.api.TagChangesItemDelete import __TagChangesItemDeleteSerDer__
        deleteValue = value['delete']
        instance.delete = serder.ListSerDer(
            __TagChangesItemDeleteSerDer__()).parse(deleteValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.tag.api.TagChangesItemAdd import TagChangesItemAdd
        from netbluemind.tag.api.TagChangesItemAdd import __TagChangesItemAddSerDer__
        addValue = value.add
        instance["add"] = serder.ListSerDer(
            __TagChangesItemAddSerDer__()).encode(addValue)
        from netbluemind.tag.api.TagChangesItemModify import TagChangesItemModify
        from netbluemind.tag.api.TagChangesItemModify import __TagChangesItemModifySerDer__
        modifyValue = value.modify
        instance["modify"] = serder.ListSerDer(
            __TagChangesItemModifySerDer__()).encode(modifyValue)
        from netbluemind.tag.api.TagChangesItemDelete import TagChangesItemDelete
        from netbluemind.tag.api.TagChangesItemDelete import __TagChangesItemDeleteSerDer__
        deleteValue = value.delete
        instance["delete"] = serder.ListSerDer(
            __TagChangesItemDeleteSerDer__()).encode(deleteValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IExternalUser_VERSION = "5.0.7574"


class IExternalUser(BaseEndpoint):
    def __init__(self, apiKey, url, domainUid):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/externaluser/{domainUid}'
        self.domainUid_ = domainUid
        self.base = self.base.replace('{domainUid}', domainUid)

    def byExtId(self, extid):
        postUri = "/byExtId/{extid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{extid}", extid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalUser_VERSION}, data=__encoded__)
        from netbluemind.externaluser.api.ExternalUser import ExternalUser
        from netbluemind.externaluser.api.ExternalUser import __ExternalUserSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__ExternalUserSerDer__()), response)

    def create(self, uid, externalUser):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.externaluser.api.ExternalUser import ExternalUser
        from netbluemind.externaluser.api.ExternalUser import __ExternalUserSerDer__
        __data__ = __ExternalUserSerDer__().encode(externalUser)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def createWithExtId(self, uid, extid, externalUser):
        postUri = "/{uid}/{extid}/createwithextid"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        postUri = postUri.replace("{extid}", extid)
        from netbluemind.externaluser.api.ExternalUser import ExternalUser
        from netbluemind.externaluser.api.ExternalUser import __ExternalUserSerDer__
        __data__ = __ExternalUserSerDer__().encode(externalUser)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def delete(self, uid):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getComplete(self, uid):
        postUri = "/{uid}/complete"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalUser_VERSION}, data=__encoded__)
        from netbluemind.externaluser.api.ExternalUser import ExternalUser
        from netbluemind.externaluser.api.ExternalUser import __ExternalUserSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__ExternalUserSerDer__()), response)

    def memberOf(self, uid):
        postUri = "/{uid}/groups"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalUser_VERSION}, data=__encoded__)
        from netbluemind.group.api.Group import Group
        from netbluemind.group.api.Group import __GroupSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__GroupSerDer__())), response)

    def memberOfGroups(self, uid):
        postUri = "/{uid}/groupUids"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalUser_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)

    def update(self, uid, externalUser):
        postUri = "/{uid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        from netbluemind.externaluser.api.ExternalUser import ExternalUser
        from netbluemind.externaluser.api.ExternalUser import __ExternalUserSerDer__
        __data__ = __ExternalUserSerDer__().encode(externalUser)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IExternalUser_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class HotUpgradeTaskFilter:
    def __init__(self):
        self.operation = None
        self.statuses = None
        self.onlyRetryable = None
        self.onlyReady = None
        self.onlyMandatory = None
        self.mode = None
        pass


class __HotUpgradeTaskFilterSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = HotUpgradeTaskFilter()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        operationValue = value['operation']
        instance.operation = serder.STRING.parse(operationValue)
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskStatus import HotUpgradeTaskStatus
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskStatus import __HotUpgradeTaskStatusSerDer__
        statusesValue = value['statuses']
        instance.statuses = serder.ListSerDer(
            __HotUpgradeTaskStatusSerDer__()).parse(statusesValue)
        onlyRetryableValue = value['onlyRetryable']
        instance.onlyRetryable = serder.BOOLEAN.parse(onlyRetryableValue)
        onlyReadyValue = value['onlyReady']
        instance.onlyReady = serder.BOOLEAN.parse(onlyReadyValue)
        onlyMandatoryValue = value['onlyMandatory']
        instance.onlyMandatory = serder.BOOLEAN.parse(onlyMandatoryValue)
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import HotUpgradeTaskExecutionMode
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import __HotUpgradeTaskExecutionModeSerDer__
        modeValue = value['mode']
        instance.mode = serder.ListSerDer(
            __HotUpgradeTaskExecutionModeSerDer__()).parse(modeValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        operationValue = value.operation
        instance["operation"] = serder.STRING.encode(operationValue)
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskStatus import HotUpgradeTaskStatus
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskStatus import __HotUpgradeTaskStatusSerDer__
        statusesValue = value.statuses
        instance["statuses"] = serder.ListSerDer(
            __HotUpgradeTaskStatusSerDer__()).encode(statusesValue)
        onlyRetryableValue = value.onlyRetryable
        instance["onlyRetryable"] = serder.BOOLEAN.encode(onlyRetryableValue)
        onlyReadyValue = value.onlyReady
        instance["onlyReady"] = serder.BOOLEAN.encode(onlyReadyValue)
        onlyMandatoryValue = value.onlyMandatory
        instance["onlyMandatory"] = serder.BOOLEAN.encode(onlyMandatoryValue)
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import HotUpgradeTaskExecutionMode
        from netbluemind.system.api.hot.upgrade.HotUpgradeTaskExecutionMode import __HotUpgradeTaskExecutionModeSerDer__
        modeValue = value.mode
        instance["mode"] = serder.ListSerDer(
            __HotUpgradeTaskExecutionModeSerDer__()).encode(modeValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class ContainerSubscription:
    def __init__(self):
        self.containerUid = None
        self.offlineSync = None
        self.automount = None
        pass


class __ContainerSubscriptionSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ContainerSubscription()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        containerUidValue = value['containerUid']
        instance.containerUid = serder.STRING.parse(containerUidValue)
        offlineSyncValue = value['offlineSync']
        instance.offlineSync = serder.BOOLEAN.parse(offlineSyncValue)
        automountValue = value['automount']
        instance.automount = serder.BOOLEAN.parse(automountValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        containerUidValue = value.containerUid
        instance["containerUid"] = serder.STRING.encode(containerUidValue)
        offlineSyncValue = value.offlineSync
        instance["offlineSync"] = serder.BOOLEAN.encode(offlineSyncValue)
        automountValue = value.automount
        instance["automount"] = serder.BOOLEAN.encode(automountValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IDirectory_VERSION = "5.0.7574"


class IDirectory(BaseEndpoint):
    def __init__(self, apiKey, url, domain):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/directory/{domain}'
        self.domain_ = domain
        self.base = self.base.replace('{domain}', domain)

    def changeset(self, since):
        postUri = "/_changeset"
        __data__ = None
        __encoded__ = None
        queryParams = {'since': since}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.core.container.model.ContainerChangeset import ContainerChangeset
        from netbluemind.core.container.model.ContainerChangeset import __ContainerChangesetSerDer__
        return self.handleResult__(__ContainerChangesetSerDer__(serder.STRING), response)

    def delete(self, path):
        postUri = "/{path}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{path}", path)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def deleteByEntryUid(self, entryUid):
        postUri = "/_byentryuid/{entryUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{entryUid}", entryUid)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)

    def findByEntryUid(self, entryUid):
        postUri = "/entry-uid/{entryUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{entryUid}", entryUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.directory.api.DirEntry import DirEntry
        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
        return self.handleResult__(__DirEntrySerDer__(), response)

    def getByEmail(self, email):
        postUri = "/_byEmail/{email}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{email}", email)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.directory.api.DirEntry import DirEntry
        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
        return self.handleResult__(__DirEntrySerDer__(), response)

    def getByRoles(self, roles):
        postUri = "/_byroles"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(roles)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.directory.api.DirEntry import DirEntry
        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__DirEntrySerDer__())), response)

    def getEntries(self, path):
        postUri = "/_childs"
        __data__ = None
        __encoded__ = None
        __data__ = serder.STRING.encode(path)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.directory.api.DirEntry import DirEntry
        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
        return self.handleResult__(serder.ListSerDer(__DirEntrySerDer__()), response)

    def getEntry(self, path):
        postUri = "/_entry"
        __data__ = None
        __encoded__ = None
        __data__ = serder.STRING.encode(path)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.directory.api.DirEntry import DirEntry
        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
        return self.handleResult__(__DirEntrySerDer__(), response)

    def getEntryIcon(self, entryUid):
        postUri = "/entry-uid/{entryUid}/icon"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{entryUid}", entryUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ByteArraySerDer, response)

    def getEntryPhoto(self, entryUid):
        postUri = "/entry-uid/{entryUid}/photo"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{entryUid}", entryUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ByteArraySerDer, response)

    def getIcon(self, path):
        postUri = "/_icon/{path}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{path}", path)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        return self.handleResult__(serder.ByteArraySerDer, response)

    def getMultiple(self, id):
        postUri = "/_mget"
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(id)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.directory.api.DirEntry import DirEntry
        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__DirEntrySerDer__())), response)

    def getRolesForDirEntry(self, entryUid):
        postUri = "/entry-uid/{entryUid}/rolesfor_"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{entryUid}", entryUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)

    def getRolesForOrgUnit(self, ouUid):
        postUri = "/ou-uid/{ouUid}/rolesfor_"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{ouUid}", ouUid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)

    def getRoot(self):
        postUri = ""
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.directory.api.DirEntry import DirEntry
        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
        return self.handleResult__(__DirEntrySerDer__(), response)

    def getVCard(self, uid):
        postUri = "/{uid}/_vcard"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}", uid)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.addressbook.api.VCard import VCard
        from netbluemind.addressbook.api.VCard import __VCardSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__VCardSerDer__()), response)

    def search(self, query):
        postUri = "/_search"
        __data__ = None
        __encoded__ = None
        from netbluemind.directory.api.DirEntryQuery import DirEntryQuery
        from netbluemind.directory.api.DirEntryQuery import __DirEntryQuerySerDer__
        __data__ = __DirEntryQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.directory.api.DirEntry import DirEntry
        from netbluemind.directory.api.DirEntry import __DirEntrySerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        from netbluemind.core.api.ListResult import ListResult
        from netbluemind.core.api.ListResult import __ListResultSerDer__
        return self.handleResult__(__ListResultSerDer__(__ItemValueSerDer__(__DirEntrySerDer__())), response)

    def xfer(self, entryUid, serverUid):
        postUri = "/_xfer/{entryUid}/{serverUid}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{entryUid}", entryUid)
        postUri = postUri.replace("{serverUid}", serverUid)
        queryParams = {}

        response = requests.post(self.base + postUri, params=queryParams, verify=False, headers={
                                 'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IDirectory_VERSION}, data=__encoded__)
        from netbluemind.core.task.api.TaskRef import TaskRef
        from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
        return self.handleResult__(__TaskRefSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder
from enum import Enum


class MailFilterRuleConditionOperator(Enum):
    OR = 'OR'
    AND = 'AND'


class __MailFilterRuleConditionOperatorSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MailFilterRuleConditionOperator[value]
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = value.value
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class MessageSearchResult:
    def __init__(self):
        self.containerUid = None
        self.itemId = None
        self.subject = None
        self.size = None
        self.messageClass = None
        self.date = None
        self.from_ = None
        self.to = None
        self.seen = None
        self.flagged = None
        self.hasAttachment = None
        self.preview = None
        pass


class __MessageSearchResultSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = MessageSearchResult()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        containerUidValue = value['containerUid']
        instance.containerUid = serder.STRING.parse(containerUidValue)
        itemIdValue = value['itemId']
        instance.itemId = serder.INT.parse(itemIdValue)
        subjectValue = value['subject']
        instance.subject = serder.STRING.parse(subjectValue)
        sizeValue = value['size']
        instance.size = serder.INT.parse(sizeValue)
        messageClassValue = value['messageClass']
        instance.messageClass = serder.STRING.parse(messageClassValue)
        dateValue = value['date']
        instance.date = serder.DATE.parse(dateValue)
        from netbluemind.backend.mail.api.MessageSearchResultMbox import MessageSearchResultMbox
        from netbluemind.backend.mail.api.MessageSearchResultMbox import __MessageSearchResultMboxSerDer__
        from_Value = value['from']
        instance.from_ = __MessageSearchResultMboxSerDer__().parse(from_Value)
        from netbluemind.backend.mail.api.MessageSearchResultMbox import MessageSearchResultMbox
        from netbluemind.backend.mail.api.MessageSearchResultMbox import __MessageSearchResultMboxSerDer__
        toValue = value['to']
        instance.to = __MessageSearchResultMboxSerDer__().parse(toValue)
        seenValue = value['seen']
        instance.seen = serder.BOOLEAN.parse(seenValue)
        flaggedValue = value['flagged']
        instance.flagged = serder.BOOLEAN.parse(flaggedValue)
        hasAttachmentValue = value['hasAttachment']
        instance.hasAttachment = serder.BOOLEAN.parse(hasAttachmentValue)
        previewValue = value['preview']
        instance.preview = serder.STRING.parse(previewValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        containerUidValue = value.containerUid
        instance["containerUid"] = serder.STRING.encode(containerUidValue)
        itemIdValue = value.itemId
        instance["itemId"] = serder.INT.encode(itemIdValue)
        subjectValue = value.subject
        instance["subject"] = serder.STRING.encode(subjectValue)
        sizeValue = value.size
        instance["size"] = serder.INT.encode(sizeValue)
        messageClassValue = value.messageClass
        instance["messageClass"] = serder.STRING.encode(messageClassValue)
        dateValue = value.date
        instance["date"] = serder.DATE.encode(dateValue)
        from netbluemind.backend.mail.api.MessageSearchResultMbox import MessageSearchResultMbox
        from netbluemind.backend.mail.api.MessageSearchResultMbox import __MessageSearchResultMboxSerDer__
        from_Value = value.from_
        instance["from"] = __MessageSearchResultMboxSerDer__().encode(from_Value)
        from netbluemind.backend.mail.api.MessageSearchResultMbox import MessageSearchResultMbox
        from netbluemind.backend.mail.api.MessageSearchResultMbox import __MessageSearchResultMboxSerDer__
        toValue = value.to
        instance["to"] = __MessageSearchResultMboxSerDer__().encode(toValue)
        seenValue = value.seen
        instance["seen"] = serder.BOOLEAN.encode(seenValue)
        flaggedValue = value.flagged
        instance["flagged"] = serder.BOOLEAN.encode(flaggedValue)
        hasAttachmentValue = value.hasAttachment
        instance["hasAttachment"] = serder.BOOLEAN.encode(hasAttachmentValue)
        previewValue = value.preview
        instance["preview"] = serder.STRING.encode(previewValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class ICalendarElementAttendee:
    def __init__(self):
        self.cutype = None
        self.member = None
        self.role = None
        self.partStatus = None
        self.rsvp = None
        self.delTo = None
        self.delFrom = None
        self.sentBy = None
        self.commonName = None
        self.dir = None
        self.lang = None
        self.mailto = None
        self.uri = None
        self.internal = None
        self.responseComment = None
        self.counter = None
        pass


class __ICalendarElementAttendeeSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ICalendarElementAttendee()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.icalendar.api.ICalendarElementCUType import ICalendarElementCUType
        from netbluemind.icalendar.api.ICalendarElementCUType import __ICalendarElementCUTypeSerDer__
        cutypeValue = value['cutype']
        instance.cutype = __ICalendarElementCUTypeSerDer__().parse(cutypeValue)
        memberValue = value['member']
        instance.member = serder.STRING.parse(memberValue)
        from netbluemind.icalendar.api.ICalendarElementRole import ICalendarElementRole
        from netbluemind.icalendar.api.ICalendarElementRole import __ICalendarElementRoleSerDer__
        roleValue = value['role']
        instance.role = __ICalendarElementRoleSerDer__().parse(roleValue)
        from netbluemind.icalendar.api.ICalendarElementParticipationStatus import ICalendarElementParticipationStatus
        from netbluemind.icalendar.api.ICalendarElementParticipationStatus import __ICalendarElementParticipationStatusSerDer__
        partStatusValue = value['partStatus']
        instance.partStatus = __ICalendarElementParticipationStatusSerDer__().parse(partStatusValue)
        rsvpValue = value['rsvp']
        instance.rsvp = serder.BOOLEAN.parse(rsvpValue)
        delToValue = value['delTo']
        instance.delTo = serder.STRING.parse(delToValue)
        delFromValue = value['delFrom']
        instance.delFrom = serder.STRING.parse(delFromValue)
        sentByValue = value['sentBy']
        instance.sentBy = serder.STRING.parse(sentByValue)
        commonNameValue = value['commonName']
        instance.commonName = serder.STRING.parse(commonNameValue)
        dirValue = value['dir']
        instance.dir = serder.STRING.parse(dirValue)
        langValue = value['lang']
        instance.lang = serder.STRING.parse(langValue)
        mailtoValue = value['mailto']
        instance.mailto = serder.STRING.parse(mailtoValue)
        uriValue = value['uri']
        instance.uri = serder.STRING.parse(uriValue)
        internalValue = value['internal']
        instance.internal = serder.BOOLEAN.parse(internalValue)
        responseCommentValue = value['responseComment']
        instance.responseComment = serder.STRING.parse(responseCommentValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        counterValue = value['counter']
        instance.counter = __BmDateTimeSerDer__().parse(counterValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.icalendar.api.ICalendarElementCUType import ICalendarElementCUType
        from netbluemind.icalendar.api.ICalendarElementCUType import __ICalendarElementCUTypeSerDer__
        cutypeValue = value.cutype
        instance["cutype"] = __ICalendarElementCUTypeSerDer__().encode(
            cutypeValue)
        memberValue = value.member
        instance["member"] = serder.STRING.encode(memberValue)
        from netbluemind.icalendar.api.ICalendarElementRole import ICalendarElementRole
        from netbluemind.icalendar.api.ICalendarElementRole import __ICalendarElementRoleSerDer__
        roleValue = value.role
        instance["role"] = __ICalendarElementRoleSerDer__().encode(roleValue)
        from netbluemind.icalendar.api.ICalendarElementParticipationStatus import ICalendarElementParticipationStatus
        from netbluemind.icalendar.api.ICalendarElementParticipationStatus import __ICalendarElementParticipationStatusSerDer__
        partStatusValue = value.partStatus
        instance["partStatus"] = __ICalendarElementParticipationStatusSerDer__().encode(
            partStatusValue)
        rsvpValue = value.rsvp
        instance["rsvp"] = serder.BOOLEAN.encode(rsvpValue)
        delToValue = value.delTo
        instance["delTo"] = serder.STRING.encode(delToValue)
        delFromValue = value.delFrom
        instance["delFrom"] = serder.STRING.encode(delFromValue)
        sentByValue = value.sentBy
        instance["sentBy"] = serder.STRING.encode(sentByValue)
        commonNameValue = value.commonName
        instance["commonName"] = serder.STRING.encode(commonNameValue)
        dirValue = value.dir
        instance["dir"] = serder.STRING.encode(dirValue)
        langValue = value.lang
        instance["lang"] = serder.STRING.encode(langValue)
        mailtoValue = value.mailto
        instance["mailto"] = serder.STRING.encode(mailtoValue)
        uriValue = value.uri
        instance["uri"] = serder.STRING.encode(uriValue)
        internalValue = value.internal
        instance["internal"] = serder.BOOLEAN.encode(internalValue)
        responseCommentValue = value.responseComment
        instance["responseComment"] = serder.STRING.encode(
            responseCommentValue)
        from netbluemind.core.api.date.BmDateTime import BmDateTime
        from netbluemind.core.api.date.BmDateTime import __BmDateTimeSerDer__
        counterValue = value.counter
        instance["counter"] = __BmDateTimeSerDer__().encode(counterValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IEas_VERSION = "5.0.7574"


class IEas(BaseEndpoint):
    def __init__(self, apiKey, url):
        self.url = url
        self.apiKey = apiKey
        self.base = url + '/eas'

    def deletePendingReset(self, account):
        postUri = "/_deletePendingReset"
        __data__ = None
        __encoded__ = None
        from netbluemind.eas.api.Account import Account
        from netbluemind.eas.api.Account import __AccountSerDer__
        __data__ = __AccountSerDer__().encode(account)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.delete(self.base + postUri, params=queryParams, verify=False, headers={
                                   'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IEas_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def getConfiguration(self):
        postUri = "/_getConfiguration"
        __data__ = None
        __encoded__ = None
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IEas_VERSION}, data=__encoded__)
        return self.handleResult__(serder.MapSerDer(serder.STRING), response)

    def getFolderSyncVersions(self, account):
        postUri = "/_getFolderSync"
        __data__ = None
        __encoded__ = None
        from netbluemind.eas.api.Account import Account
        from netbluemind.eas.api.Account import __AccountSerDer__
        __data__ = __AccountSerDer__().encode(account)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IEas_VERSION}, data=__encoded__)
        return self.handleResult__(serder.MapSerDer(serder.STRING), response)

    def getHeartbeat(self, deviceUid):
        postUri = "/_heartbeat"
        __data__ = None
        __encoded__ = None
        queryParams = {'deviceUid': deviceUid}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IEas_VERSION}, data=__encoded__)
        from netbluemind.eas.api.Heartbeat import Heartbeat
        from netbluemind.eas.api.Heartbeat import __HeartbeatSerDer__
        return self.handleResult__(__HeartbeatSerDer__(), response)

    def insertClientId(self, clientId):
        postUri = "/_sendmailId/{clientId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{clientId}", clientId)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IEas_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def insertPendingReset(self, account):
        postUri = "/_reset"
        __data__ = None
        __encoded__ = None
        from netbluemind.eas.api.Account import Account
        from netbluemind.eas.api.Account import __AccountSerDer__
        __data__ = __AccountSerDer__().encode(account)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IEas_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def isKnownClientId(self, clientId):
        postUri = "/_sendmailId/{clientId}"
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{clientId}", clientId)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IEas_VERSION}, data=__encoded__)
        return self.handleResult__(serder.BOOLEAN, response)

    def needReset(self, account):
        postUri = "/_needReset"
        __data__ = None
        __encoded__ = None
        from netbluemind.eas.api.Account import Account
        from netbluemind.eas.api.Account import __AccountSerDer__
        __data__ = __AccountSerDer__().encode(account)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.get(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IEas_VERSION}, data=__encoded__)
        return self.handleResult__(serder.BOOLEAN, response)

    def setFolderSyncVersions(self, versions):
        postUri = "/_setFolderSync"
        __data__ = None
        __encoded__ = None
        from netbluemind.eas.api.FolderSyncVersions import FolderSyncVersions
        from netbluemind.eas.api.FolderSyncVersions import __FolderSyncVersionsSerDer__
        __data__ = __FolderSyncVersionsSerDer__().encode(versions)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IEas_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)

    def setHeartbeat(self, heartbeat):
        postUri = "/_heartbeat"
        __data__ = None
        __encoded__ = None
        from netbluemind.eas.api.Heartbeat import Heartbeat
        from netbluemind.eas.api.Heartbeat import __HeartbeatSerDer__
        __data__ = __HeartbeatSerDer__().encode(heartbeat)
        __encoded__ = json.dumps(__data__)
        queryParams = {}

        response = requests.put(self.base + postUri, params=queryParams, verify=False, headers={
                                'X-BM-ApiKey': self.apiKey, 'Accept': 'application/json', 'X-BM-ClientVersion': IEas_VERSION}, data=__encoded__)
        return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class OrgUnit:
    def __init__(self):
        self.name = None
        self.parentUid = None
        pass


class __OrgUnitSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = OrgUnit()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        nameValue = value['name']
        instance.name = serder.STRING.parse(nameValue)
        parentUidValue = value['parentUid']
        instance.parentUid = serder.STRING.parse(parentUidValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        nameValue = value.name
        instance["name"] = serder.STRING.encode(nameValue)
        parentUidValue = value.parentUid
        instance["parentUid"] = serder.STRING.encode(parentUidValue)
        return instance



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class VCard:
    def __init__(self):
        self.kind = None
        self.source = None
        self.identification = None
        self.deliveryAddressing = None
        self.communications = None
        self.organizational = None
        self.explanatory = None
        self.security = None
        self.related = None
        pass


class __VCardSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = VCard()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.addressbook.api.VCardKind import VCardKind
        from netbluemind.addressbook.api.VCardKind import __VCardKindSerDer__
        kindValue = value['kind']
        instance.kind = __VCardKindSerDer__().parse(kindValue)
        sourceValue = value['source']
        instance.source = serder.STRING.parse(sourceValue)
        from netbluemind.addressbook.api.VCardIdentification import VCardIdentification
        from netbluemind.addressbook.api.VCardIdentification import __VCardIdentificationSerDer__
        identificationValue = value['identification']
        instance.identification = __VCardIdentificationSerDer__().parse(identificationValue)
        from netbluemind.addressbook.api.VCardDeliveryAddressing import VCardDeliveryAddressing
        from netbluemind.addressbook.api.VCardDeliveryAddressing import __VCardDeliveryAddressingSerDer__
        deliveryAddressingValue = value['deliveryAddressing']
        instance.deliveryAddressing = serder.ListSerDer(
            __VCardDeliveryAddressingSerDer__()).parse(deliveryAddressingValue)
        from netbluemind.addressbook.api.VCardCommunications import VCardCommunications
        from netbluemind.addressbook.api.VCardCommunications import __VCardCommunicationsSerDer__
        communicationsValue = value['communications']
        instance.communications = __VCardCommunicationsSerDer__().parse(communicationsValue)
        from netbluemind.addressbook.api.VCardOrganizational import VCardOrganizational
        from netbluemind.addressbook.api.VCardOrganizational import __VCardOrganizationalSerDer__
        organizationalValue = value['organizational']
        instance.organizational = __VCardOrganizationalSerDer__().parse(organizationalValue)
        from netbluemind.addressbook.api.VCardExplanatory import VCardExplanatory
        from netbluemind.addressbook.api.VCardExplanatory import __VCardExplanatorySerDer__
        explanatoryValue = value['explanatory']
        instance.explanatory = __VCardExplanatorySerDer__().parse(explanatoryValue)
        from netbluemind.addressbook.api.VCardSecurity import VCardSecurity
        from netbluemind.addressbook.api.VCardSecurity import __VCardSecuritySerDer__
        securityValue = value['security']
        instance.security = __VCardSecuritySerDer__().parse(securityValue)
        from netbluemind.addressbook.api.VCardRelated import VCardRelated
        from netbluemind.addressbook.api.VCardRelated import __VCardRelatedSerDer__
        relatedValue = value['related']
        instance.related = __VCardRelatedSerDer__().parse(relatedValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.addressbook.api.VCardKind import VCardKind
        from netbluemind.addressbook.api.VCardKind import __VCardKindSerDer__
        kindValue = value.kind
        instance["kind"] = __VCardKindSerDer__().encode(kindValue)
        sourceValue = value.source
        instance["source"] = serder.STRING.encode(sourceValue)
        from netbluemind.addressbook.api.VCardIdentification import VCardIdentification
        from netbluemind.addressbook.api.VCardIdentification import __VCardIdentificationSerDer__
        identificationValue = value.identification
        instance["identification"] = __VCardIdentificationSerDer__().encode(
            identificationValue)
        from netbluemind.addressbook.api.VCardDeliveryAddressing import VCardDeliveryAddressing
        from netbluemind.addressbook.api.VCardDeliveryAddressing import __VCardDeliveryAddressingSerDer__
        deliveryAddressingValue = value.deliveryAddressing
        instance["deliveryAddressing"] = serder.ListSerDer(
            __VCardDeliveryAddressingSerDer__()).encode(deliveryAddressingValue)
        from netbluemind.addressbook.api.VCardCommunications import VCardCommunications
        from netbluemind.addressbook.api.VCardCommunications import __VCardCommunicationsSerDer__
        communicationsValue = value.communications
        instance["communications"] = __VCardCommunicationsSerDer__().encode(
            communicationsValue)
        from netbluemind.addressbook.api.VCardOrganizational import VCardOrganizational
        from netbluemind.addressbook.api.VCardOrganizational import __VCardOrganizationalSerDer__
        organizationalValue = value.organizational
        instance["organizational"] = __VCardOrganizationalSerDer__().encode(
            organizationalValue)
        from netbluemind.addressbook.api.VCardExplanatory import VCardExplanatory
        from netbluemind.addressbook.api.VCardExplanatory import __VCardExplanatorySerDer__
        explanatoryValue = value.explanatory
        instance["explanatory"] = __VCardExplanatorySerDer__().encode(
            explanatoryValue)
        from netbluemind.addressbook.api.VCardSecurity import VCardSecurity
        from netbluemind.addressbook.api.VCardSecurity import __VCardSecuritySerDer__
        securityValue = value.security
        instance["security"] = __VCardSecuritySerDer__().encode(securityValue)
        from netbluemind.addressbook.api.VCardRelated import VCardRelated
        from netbluemind.addressbook.api.VCardRelated import __VCardRelatedSerDer__
        relatedValue = value.related
        instance["related"] = __VCardRelatedSerDer__().encode(relatedValue)
        return instance
